@@ -17,9 +17,12 @@
 #define ushort_unpack uint16_unpack
 #define ushort_unpack_big uint16_unpack_big
 
-#define ushort_reverse uint16_reverse
-#define ushort_big_endian uint16_big_endian
-#define ushort_little_endian uint16_little_endian
+#define ushort_little uint16_little
+#define ushort_big uint16_big
+#define ushort_littlep uint16_littlep
+#define ushort_bigp uint16_bigp
+#define ushort_littlen uint16_littlen
+#define ushort_bign uint16_bign
 
 #define USHORT_FMT UINT16_FMT
 #define USHORT_OFMT UINT16_OFMT
@@ -52,12 +55,11 @@
 #define ushort_bscan(s, u) ushort_scan_base(s, (u), 2)
 #define ushort0_bscan(s, u) ushort0_scan_base(s, (u), 2)
 
-
 #define SHORT_PACK 2
 #define short_pack uint16_pack
 #define short_pack_big uint16_pack_big
-#define short_unpack uint16_unpack
-#define short_unpack_big uint16_unpack_big
+#define short_unpack(pack, p) uint16_unpack(pack, (uint16_t *)(p))
+#define short_unpack_big(pack, p) uint16_unpack_big(pack, (uint16_t *)(p))
 
 #define SHORT_FMT (1+UINT16_FMT)
 #define short_fmt int16_fmt
@@ -73,9 +75,12 @@
 #define uint_unpack uint32_unpack
 #define uint_unpack_big uint32_unpack_big
 
-#define uint_reverse uint32_reverse
-#define uint_big_endian uint32_big_endian
-#define uint_little_endian uint32_little_endian
+#define uint_little uint32_little
+#define uint_big uint32_big
+#define uint_littlep uint32_littlep
+#define uint_bigp uint32_bigp
+#define uint_littlen uint32_littlen
+#define uint_bign uint32_bign
 
 #define UINT_FMT UINT32_FMT
 #define UINT_OFMT UINT32_OFMT
@@ -108,12 +113,11 @@
 #define uint_bscan(s, u) uint_scan_base(s, (u), 2)
 #define uint0_bscan(s, u) uint0_scan_base(s, (u), 2)
 
-
 #define INT_PACK 4
 #define int_pack uint32_pack
 #define int_pack_big uint32_pack_big
-#define int_unpack uint32_unpack
-#define int_unpack_big uint32_unpack_big
+#define int_unpack(pack, p) uint32_unpack(pack, (uint32_t *)(p))
+#define int_unpack_big(pack, p) uint32_unpack_big(pack, (uint32_t *)(p))
 
 #define INT_FMT (1+UINT32_FMT)
 #define int_fmt int32_fmt
@@ -123,37 +127,40 @@
 #define int_scanlist int32_scanlist
 
 
-#define ULONG_PACK 8
-#define ulong_pack uint64_pack
-#define ulong_pack_big uint64_pack_big
-#define ulong_unpack uint64_unpack
-#define ulong_unpack_big uint64_unpack_big
+#define ULONG_PACK 4
+#define ulong_pack uint32_pack
+#define ulong_pack_big uint32_pack_big
+#define ulong_unpack uint32_unpack
+#define ulong_unpack_big uint32_unpack_big
 
-#define ulong_reverse uint64_reverse
-#define ulong_big_endian uint64_big_endian
-#define ulong_little_endian uint64_little_endian
+#define ulong_little uint32_little
+#define ulong_big uint32_big
+#define ulong_littlep uint32_littlep
+#define ulong_bigp uint32_bigp
+#define ulong_littlen uint32_littlen
+#define ulong_bign uint32_bign
 
-#define ULONG_FMT UINT64_FMT
-#define ULONG_OFMT UINT64_OFMT
-#define ULONG_XFMT UINT64_XFMT
-#define ULONG_BFMT UINT64_BFMT
+#define ULONG_FMT UINT32_FMT
+#define ULONG_OFMT UINT32_OFMT
+#define ULONG_XFMT UINT32_XFMT
+#define ULONG_BFMT UINT32_BFMT
 
-#define ulong_fmt_base uint64_fmt_base
-#define ulong0_fmt_base uint640_fmt_base
-#define ulong_fmt uint64_fmt
-#define ulong0_fmt uint640_fmt
-#define ulong_ofmt uint64_ofmt
-#define ulong0_ofmt uint640_ofmt
-#define ulong_xfmt uint64_xfmt
-#define ulong0_xfmt uint640_xfmt
-#define ulong_bfmt uint64_bfmt
-#define ulong0_bfmt uint640_bfmt
+#define ulong_fmt_base uint32_fmt_base
+#define ulong0_fmt_base uint320_fmt_base
+#define ulong_fmt uint32_fmt
+#define ulong0_fmt uint320_fmt
+#define ulong_ofmt uint32_ofmt
+#define ulong0_ofmt uint320_ofmt
+#define ulong_xfmt uint32_xfmt
+#define ulong0_xfmt uint320_xfmt
+#define ulong_bfmt uint32_bfmt
+#define ulong0_bfmt uint320_bfmt
 
-#define ulong_fmtlist uint64_fmtlist
+#define ulong_fmtlist uint32_fmtlist
 
-#define ulong_scan_base uint64_scan_base
-#define ulong0_scan_base uint640_scan_base
-#define ulong_scanlist uint64_scanlist
+#define ulong_scan_base uint32_scan_base
+#define ulong0_scan_base uint320_scan_base
+#define ulong_scanlist uint32_scanlist
 
 #define ulong_scan(s, u) ulong_scan_base(s, (u), 10)
 #define ulong0_scan(s, u) ulong0_scan_base(s, (u), 10)
@@ -164,52 +171,54 @@
 #define ulong_bscan(s, u) ulong_scan_base(s, (u), 2)
 #define ulong0_bscan(s, u) ulong0_scan_base(s, (u), 2)
 
+#define LONG_PACK 4
+#define long_pack uint32_pack
+#define long_pack_big uint32_pack_big
+#define long_unpack(pack, p) uint32_unpack(pack, (uint32_t *)(p))
+#define long_unpack_big(pack, p) uint32_unpack_big(pack, (uint32_t *)(p))
 
-#define LONG_PACK 8
-#define long_pack uint64_pack
-#define long_pack_big uint64_pack_big
-#define long_unpack uint64_unpack
-#define long_unpack_big uint64_unpack_big
-
-#define LONG_FMT (1+UINT64_FMT)
-#define long_fmt int64_fmt
-#define long_fmtlist int64_fmtlist
-#define long_scan int64_scan
-#define long0_scan int640_scan
-#define long_scanlist int64_scanlist
+#define LONG_FMT (1+UINT32_FMT)
+#define long_fmt int32_fmt
+#define long_fmtlist int32_fmtlist
+#define long_scan int32_scan
+#define long0_scan int320_scan
+#define long_scanlist int32_scanlist
 
 
-#define SIZE_PACK 8
-#define size_pack uint64_pack
-#define size_pack_big uint64_pack_big
-#define size_unpack uint64_unpack
-#define size_unpack_big uint64_unpack_big
+#define SIZE_PACK 4
+#define size_pack uint32_pack
+#define size_pack_big uint32_pack_big
+#define size_unpack uint32_unpack
+#define size_unpack_big uint32_unpack_big
 
-#define size_reverse uint64_reverse
-#define size_big_endian uint64_big_endian
-#define size_little_endian uint64_little_endian
+#define size_little uint32_little
+#define size_big uint32_big
+#define size_littlep uint32_littlep
+#define size_bigp uint32_bigp
+#define size_littlen uint32_littlen
+#define size_bign uint32_bign
 
-#define SIZE_FMT UINT64_FMT
-#define SIZE_OFMT UINT64_OFMT
-#define SIZE_XFMT UINT64_XFMT
-#define SIZE_BFMT UINT64_BFMT
+#define SIZE_FMT UINT32_FMT
+#define SIZE_OFMT UINT32_OFMT
+#define SIZE_XFMT UINT32_XFMT
+#define SIZE_BFMT UINT32_BFMT
 
-#define size_fmt_base uint64_fmt_base
-#define size0_fmt_base uint640_fmt_base
-#define size_fmt uint64_fmt
-#define size0_fmt uint640_fmt
-#define size_ofmt uint64_ofmt
-#define size0_ofmt uint640_ofmt
-#define size_xfmt uint64_xfmt
-#define size0_xfmt uint640_xfmt
-#define size_bfmt uint64_bfmt
-#define size0_bfmt uint640_bfmt
+#define size_fmt_base uint32_fmt_base
+#define size0_fmt_base uint320_fmt_base
+#define size_fmt uint32_fmt
+#define size0_fmt uint320_fmt
+#define size_ofmt uint32_ofmt
+#define size0_ofmt uint320_ofmt
+#define size_xfmt uint32_xfmt
+#define size0_xfmt uint320_xfmt
+#define size_bfmt uint32_bfmt
+#define size0_bfmt uint320_bfmt
 
-#define size_fmtlist uint64_fmtlist
+#define size_fmtlist uint32_fmtlist
 
-#define size_scan_base uint64_scan_base
-#define size0_scan_base uint640_scan_base
-#define size_scanlist uint64_scanlist
+#define size_scan_base uint32_scan_base
+#define size0_scan_base uint320_scan_base
+#define size_scanlist uint32_scanlist
 
 #define size_scan(s, u) size_scan_base(s, (u), 10)
 #define size0_scan(s, u) size0_scan_base(s, (u), 10)
@@ -220,16 +229,18 @@
 #define size_bscan(s, u) size_scan_base(s, (u), 2)
 #define size0_bscan(s, u) size0_scan_base(s, (u), 2)
 
-
 #define UID_PACK 4
 #define uid_pack uint32_pack
 #define uid_pack_big uint32_pack_big
 #define uid_unpack uint32_unpack
 #define uid_unpack_big uint32_unpack_big
 
-#define uid_reverse uint32_reverse
-#define uid_big_endian uint32_big_endian
-#define uid_little_endian uint32_little_endian
+#define uid_little uint32_little
+#define uid_big uint32_big
+#define uid_littlep uint32_littlep
+#define uid_bigp uint32_bigp
+#define uid_littlen uint32_littlen
+#define uid_bign uint32_bign
 
 #define UID_FMT UINT32_FMT
 #define UID_OFMT UINT32_OFMT
@@ -262,16 +273,18 @@
 #define uid_bscan(s, u) uid_scan_base(s, (u), 2)
 #define uid0_bscan(s, u) uid0_scan_base(s, (u), 2)
 
-
 #define GID_PACK 4
 #define gid_pack uint32_pack
 #define gid_pack_big uint32_pack_big
 #define gid_unpack uint32_unpack
 #define gid_unpack_big uint32_unpack_big
 
-#define gid_reverse uint32_reverse
-#define gid_big_endian uint32_big_endian
-#define gid_little_endian uint32_little_endian
+#define gid_little uint32_little
+#define gid_big uint32_big
+#define gid_littlep uint32_littlep
+#define gid_bigp uint32_bigp
+#define gid_littlen uint32_littlen
+#define gid_bign uint32_bign
 
 #define GID_FMT UINT32_FMT
 #define GID_OFMT UINT32_OFMT
@@ -304,12 +317,11 @@
 #define gid_bscan(s, u) gid_scan_base(s, (u), 2)
 #define gid0_bscan(s, u) gid0_scan_base(s, (u), 2)
 
-
 #define PID_PACK 4
 #define pid_pack uint32_pack
 #define pid_pack_big uint32_pack_big
-#define pid_unpack uint32_unpack
-#define pid_unpack_big uint32_unpack_big
+#define pid_unpack(pack, p) uint32_unpack(pack, (uint32_t *)(p))
+#define pid_unpack_big(pack, p) uint32_unpack_big(pack, (uint32_t *)(p))
 
 #define PID_FMT (1+UINT32_FMT)
 #define pid_fmt int32_fmt
@@ -322,8 +334,8 @@
 #define TIME_PACK 8
 #define time_pack uint64_pack
 #define time_pack_big uint64_pack_big
-#define time_unpack uint64_unpack
-#define time_unpack_big uint64_unpack_big
+#define time_unpack(pack, p) uint64_unpack(pack, (uint64_t *)(p))
+#define time_unpack_big(pack, p) uint64_unpack_big(pack, (uint64_t *)(p))
 
 #define TIME_FMT (1+UINT64_FMT)
 #define time_fmt int64_fmt
@@ -339,9 +351,12 @@
 #define dev_unpack uint64_unpack
 #define dev_unpack_big uint64_unpack_big
 
-#define dev_reverse uint64_reverse
-#define dev_big_endian uint64_big_endian
-#define dev_little_endian uint64_little_endian
+#define dev_little uint64_little
+#define dev_big uint64_big
+#define dev_littlep uint64_littlep
+#define dev_bigp uint64_bigp
+#define dev_littlen uint64_littlen
+#define dev_bign uint64_bign
 
 #define DEV_FMT UINT64_FMT
 #define DEV_OFMT UINT64_OFMT
@@ -374,16 +389,18 @@
 #define dev_bscan(s, u) dev_scan_base(s, (u), 2)
 #define dev0_bscan(s, u) dev0_scan_base(s, (u), 2)
 
-
 #define INO_PACK 8
 #define ino_pack uint64_pack
 #define ino_pack_big uint64_pack_big
 #define ino_unpack uint64_unpack
 #define ino_unpack_big uint64_unpack_big
 
-#define ino_reverse uint64_reverse
-#define ino_big_endian uint64_big_endian
-#define ino_little_endian uint64_little_endian
+#define ino_little uint64_little
+#define ino_big uint64_big
+#define ino_littlep uint64_littlep
+#define ino_bigp uint64_bigp
+#define ino_littlen uint64_littlen
+#define ino_bign uint64_bign
 
 #define INO_FMT UINT64_FMT
 #define INO_OFMT UINT64_OFMT
@@ -417,5 +434,4 @@
 #define ino0_bscan(s, u) ino0_scan_base(s, (u), 2)
 
 
-
 #endif
